@@ -1,20 +1,22 @@
 package Moose;
+BEGIN {
+  $Moose::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::VERSION = '2.0000';
+}
 use strict;
 use warnings;
 
 use 5.008;
 
-our $VERSION   = '1.24';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Scalar::Util 'blessed';
 use Carp         'confess';
 
 use Moose::Deprecated;
 use Moose::Exporter;
 
-use Class::MOP 1.10;
+use Class::MOP;
 
 use Moose::Meta::Class;
 use Moose::Meta::TypeConstraint;
@@ -136,7 +138,8 @@ sub init_meta {
     if ( $_[0] ne __PACKAGE__ ) {
         Moose::Deprecated::deprecated(
             feature => 'Moose::init_meta',
-            message => 'Calling Moose::init_meta as a function is deprecated',
+            message => 'Calling Moose::init_meta as a function is deprecated.'
+                . ' Doing so will throw an error in Moose 2.0200.'
         );
 
         return __PACKAGE__->init_meta(
@@ -272,7 +275,9 @@ Moose::Meta::Mixin::AttributeCore->meta->make_immutable(
 
 1;
 
-__END__
+# ABSTRACT: A postmodern object system for Perl 5
+
+
 
 =pod
 
@@ -280,6 +285,10 @@ __END__
 
 Moose - A postmodern object system for Perl 5
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   package Point;
@@ -311,7 +320,7 @@ Moose - A postmodern object system for Perl 5
 Moose is an extension of the Perl 5 object system.
 
 The main goal of Moose is to make Perl 5 Object Oriented programming
-easier, more consistent and less tedious. With Moose you can to think
+easier, more consistent, and less tedious. With Moose you can think
 more about what you want to do and less about the mechanics of OOP.
 
 Additionally, Moose is built on top of L<Class::MOP>, which is a
@@ -480,7 +489,9 @@ say anything about the attribute's value, which can be C<undef>.
 
 This will tell the class to store the value of this attribute as a weakened
 reference. If an attribute is a weakened reference, it B<cannot> also be
-coerced.
+coerced. Note that when a weak ref expires, the attribute's value becomes
+undefined, and is still considered to be set for purposes of predicate,
+default, etc.
 
 =item I<lazy =E<gt> (1|0)>
 
@@ -501,7 +512,7 @@ either C<ArrayRef> or C<HashRef>.
 
 The I<trigger> option is a CODE reference which will be called after
 the value of the attribute is set. The CODE ref is passed the
-instance itself, the updated value, and the original value if the 
+instance itself, the updated value, and the original value if the
 attribute was already set.
 
 You B<can> have a trigger on a read-only attribute.
@@ -573,7 +584,7 @@ quick example (soon to be expanded into a Moose::Cookbook recipe):
   has 'parent' => (
       is          => 'rw',
       isa         => 'Tree',
-      weak_ref => 1,
+      weak_ref    => 1,
       handles     => {
           parent_node => 'node',
           siblings    => 'children',
@@ -618,7 +629,7 @@ is consistent with role composition).
 =item C<DUCKTYPE>
 
 With the duck type option, you pass a duck type object whose "interface" then
-becomes the list of methods to handle. The "interface" can be defined as; the
+becomes the list of methods to handle. The "interface" can be defined as the
 list of methods passed to C<duck_type> to create a duck type object. For more
 information on C<duck_type> please check
 L<Moose::Util::TypeConstraints>.
@@ -641,7 +652,7 @@ a HASH ref) of the methods you want mapped.
 This tells the class to use a custom attribute metaclass for this particular
 attribute. Custom attribute metaclasses are useful for extending the
 capabilities of the I<has> keyword: they are the simplest way to extend the MOP,
-but they are still a fairly advanced topic and too much to cover here, see
+but they are still a fairly advanced topic and too much to cover here. See
 L<Moose::Cookbook::Meta::Recipe1> for more information.
 
 See L<Metaclass and Trait Name Resolution> for details on how a metaclass name
@@ -664,7 +675,7 @@ example.
 The value of this key is the name of the method that will be called to
 obtain the value used to initialize the attribute. See the L<builder
 option docs in Class::MOP::Attribute|Class::MOP::Attribute/builder>
- and/or L<Moose::Cookbook::Basics::Recipe8> for more information.
+and/or L<Moose::Cookbook::Basics::Recipe8> for more information.
 
 =item I<default> => SCALAR | CODE
 
@@ -679,16 +690,19 @@ information.
 
 =item I<clearer> => Str
 
-Creates a method allowing you to clear the value, see the L<clearer option
+Creates a method allowing you to clear the value. See the L<clearer option
 docs in Class::MOP::Attribute|Class::MOP::Attribute/clearer> for more
 information.
 
 =item I<predicate> => Str
 
 Creates a method to perform a basic test to see if a value has been set in the
-attribute, see the L<predicate option docs in
+attribute. See the L<predicate option docs in
 Class::MOP::Attribute|Class::MOP::Attribute/predicate> for more information.
 
+Note that the predicate will return true even for a C<weak_ref> attribute
+whose value has expired.
+
 =item I<lazy_build> => (0|1)
 
 Automatically define lazy => 1 as well as builder => "_build_$attr", clearer =>
@@ -709,8 +723,6 @@ information.
 An arbitrary string that can be retrieved later by calling C<<
 $attr->documentation >>.
 
-
-
 =back
 
 =item B<has +$name =E<gt> %options>
@@ -867,7 +879,7 @@ all the time.
 
 =item B<blessed>
 
-This is the C<Scalar::Util::blessed> function, it is exported here because I
+This is the C<Scalar::Util::blessed> function. It is exported here because I
 use it all the time. It is highly recommended that this is used instead of
 C<ref> anywhere you need to test for an object's class name.
 
@@ -967,7 +979,7 @@ for you.
 
 =head2 B<throw_error>
 
-An alias for C<confess>, used by internally by Moose.
+An alias for C<confess>, used internally by Moose.
 
 =head2 The MooseX:: namespace
 
@@ -998,7 +1010,7 @@ modules, many of which apply roles to the metaclass.
 
 If the parent and child do differ by roles, Moose replaces the
 metaclass in the child with a newly created metaclass. This metaclass
-is a subclass of the parent's metaclass, does all of the roles that
+is a subclass of the parent's metaclass which does all of the roles that
 the child's metaclass did before being replaced. Effectively, this
 means the new metaclass does all of the roles done by both the
 parent's and child's original metaclasses.
@@ -1091,7 +1103,7 @@ See L<http://search.cpan.org/search?query=MooseX::> for extensions.
 
 =item The Art of the MetaObject Protocol
 
-I mention this in the L<Class::MOP> docs too, this book was critical in
+I mention this in the L<Class::MOP> docs too, as this book was critical in
 the development of both modules and is highly recommended.
 
 =back
@@ -1133,17 +1145,11 @@ L<irc://irc.perl.org/#moose> to discuss. The
 L<Moose::Manual::Contributing> has more detail about how and when you
 can contribute.
 
-=head1 AUTHOR
+=head1 CABAL
 
-Moose is an open project, there are at this point dozens of people who have
-contributed, and can contribute. If you have added anything to the Moose
-project you have a commit bit on this file and can add your name to the list.
-
-=head2 CABAL
-
-However there are only a few people with the rights to release a new version
+There are only a few people with the rights to release a new version
 of Moose. The Moose Cabal are the people to go to with questions regarding
-the wider purview of Moose, and help out maintaining not just the code
+the wider purview of Moose. They help maintain not just the code
 but the community as well.
 
 Stevan (stevan) Little E<lt>stevan@iinteractive.comE<gt>
@@ -1162,7 +1168,7 @@ Florian Ragwitz E<lt>rafl@debian.orgE<gt>
 
 Dave (autarch) Rolsky E<lt>autarch@urth.orgE<gt>
 
-=head2 OTHER CONTRIBUTORS
+=head1 CONTRIBUTORS
 
 Aankhen
 
@@ -1170,47 +1176,71 @@ Adam (Alias) Kennedy
 
 Anders (Debolaz) Nor Berle
 
-Nathan (kolibrie) Gray
+Chris (perigrin) Prather
 
 Christian (chansen) Hansen
 
-Eric (ewilhelm) Wilhelm
-
-Guillermo (groditi) Roditi
-
-Jess (castaway) Robinson
-
-Matt (mst) Trout
-
-Robert (phaylon) Sedlacek
-
-Robert (rlb3) Boone
-
-Scott (konobi) McWhirter
-
-Shlomi (rindolf) Fish
-
-Wallace (wreis) Reis
-
-Jonathan (jrockway) Rockway
-
-Piotr (dexter) Roszatycki
-
-Sam (mugwump) Vilain
-
 Cory (gphat) Watson
 
 Dylan Hardison (doc fixes)
 
+Eric (ewilhelm) Wilhelm
+
+Evan Carroll
+
+Florian (rafl) Ragwitz
+
+Guillermo (groditi) Roditi
+
+Jason May
+
+Jay Hannah
+
+Jess (castaway) Robinson
+
+Jonathan (jrockway) Rockway
+
+Matt (mst) Trout
+
+Nathan (kolibrie) Gray
+
+Paul (frodwith) Driver
+
+Piotr (dexter) Roszatycki
+
+Robert Buels
+
+Robert (phaylon) Sedlacek
+
+Robert (rlb3) Boone
+
+Sam (mugwump) Vilain
+
+Scott (konobi) McWhirter
+
+Shawn (Sartak) Moore
+
+Shlomi (rindolf) Fish
+
+Tom (dec) Lanyon
+
+Wallace (wreis) Reis
+
 ... and many other #moose folks
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
