@@ -1,12 +1,14 @@
 package Moose::Error::Croak;
+BEGIN {
+  $Moose::Error::Croak::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Error::Croak::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base qw(Moose::Error::Default);
 
 sub new {
@@ -14,9 +16,11 @@ sub new {
     $self->create_error_croak(@args);
 }
 
-__PACKAGE__
+1;
+
+# ABSTRACT: Prefer C<croak>
+
 
-__END__
 
 =pod
 
@@ -24,6 +28,10 @@ __END__
 
 Moose::Error::Croak - Prefer C<croak>
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
     # Metaclass definition must come before Moose is used.
@@ -49,6 +57,21 @@ Overrides L<Moose::Error::Default/new> to prefer C<croak>.
 
 =back
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 
+__END__
+
+
+
