@@ -1,12 +1,14 @@
 package Moose::Error::Default;
+BEGIN {
+  $Moose::Error::Default::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Error::Default::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Carp::Heavy;
 use Class::MOP::MiniTrait;
 
@@ -50,9 +52,11 @@ sub _create_error_carpmess {
     }
 }
 
-__PACKAGE__
+1;
+
+# ABSTRACT: L<Carp> based error generation for Moose.
+
 
-__END__
 
 =pod
 
@@ -60,6 +64,10 @@ __END__
 
 Moose::Error::Default - L<Carp> based error generation for Moose.
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class implements L<Carp> based error generation.
@@ -87,6 +95,21 @@ Creates a new errors string of the specified style.
 
 =back
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 
+__END__
+
+
+
