@@ -1,12 +1,22 @@
 package Moose::Exporter;
+BEGIN {
+  $Moose::Exporter::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Exporter::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.24';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+use XSLoader;
+
+BEGIN {
+    XSLoader::load(
+        'Moose',
+        $Moose::Exporter::{VERSION} ? ${ $Moose::Exporter::{VERSION} } : ()
+    );
+}
 
 use Class::MOP;
 use List::MoreUtils qw( first_index uniq );
@@ -15,16 +25,12 @@ use Scalar::Util qw(reftype);
 use Sub::Exporter 0.980;
 use Sub::Name qw(subname);
 
-use XSLoader;
-
-XSLoader::load( 'Moose', $XS_VERSION );
-
 my %EXPORT_SPEC;
 
 sub setup_import_methods {
     my ( $class, %args ) = @_;
 
-    my $exporting_package = $args{exporting_package} ||= caller();
+    $args{exporting_package} ||= caller();
 
     $class->build_import_methods(
         %args,
@@ -196,7 +202,7 @@ sub _make_sub_exporter_params {
     my $class           = shift;
     my $packages        = shift;
     my $export_recorder = shift;
-    my $is_reexport  = shift;
+    my $is_reexport     = shift;
 
     my %exports;
 
@@ -373,7 +379,7 @@ sub _make_import_sub {
     my $exporting_package = shift;
     my $exporter          = shift;
     my $exports_from      = shift;
-    my $is_reexport    = shift;
+    my $is_reexport       = shift;
 
     return sub {
 
@@ -544,7 +550,7 @@ sub _make_unimport_sub {
     my $exporting_package = shift;
     my $exports           = shift;
     my $export_recorder   = shift;
-    my $is_reexport    = shift;
+    my $is_reexport       = shift;
 
     return sub {
         my $caller = scalar caller();
@@ -562,7 +568,7 @@ sub _remove_keywords {
     my $package          = shift;
     my $keywords         = shift;
     my $recorded_exports = shift;
-    my $is_reexport   = shift;
+    my $is_reexport      = shift;
 
     no strict 'refs';
 
@@ -650,12 +656,20 @@ sub import {
 
 1;
 
-__END__
+# ABSTRACT: make an import() and unimport() just like Moose.pm
+
+
+
+=pod
 
 =head1 NAME
 
 Moose::Exporter - make an import() and unimport() just like Moose.pm
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   package MyApp::Moose;
@@ -712,7 +726,7 @@ This module provides two public methods:
 
 =over 4
 
-=item  B<< Moose::Exporter->setup_import_methods(...) >>
+=item B<< Moose::Exporter->setup_import_methods(...) >>
 
 When you call this method, C<Moose::Exporter> builds custom C<import>,
 C<unimport>, and C<init_meta> methods for your module. The C<import> method
@@ -866,18 +880,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Dave Rolsky E<lt>autarch@urth.orgE<gt>
-
-This is largely a reworking of code in Moose.pm originally written by
-Stevan Little and others.
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
