@@ -1,15 +1,12 @@
 package Moose::Meta::Attribute::Native::Trait::Bool;
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Bool::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Bool::VERSION = '2.0000';
+}
 use Moose::Role;
 
-our $VERSION = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-use Moose::Meta::Method::Accessor::Native::Bool::not;
-use Moose::Meta::Method::Accessor::Native::Bool::set;
-use Moose::Meta::Method::Accessor::Native::Bool::toggle;
-use Moose::Meta::Method::Accessor::Native::Bool::unset;
-
 with 'Moose::Meta::Attribute::Native::Trait';
 
 sub _default_is  { 'rw' }
@@ -21,10 +18,6 @@ no Moose::Role;
 
 =pod
 
-=head1 NAME
-
-Moose::Meta::Attribute::Native::Trait::Bool - Helper trait for Bool attributes
-
 =head1 SYNOPSIS
 
   package Room;
@@ -89,17 +82,4 @@ Equivalent of 'not C<$value>'.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
-
-Jason May
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2010 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
