@@ -1,13 +1,12 @@
 package Moose::Meta::Attribute::Native::Trait::Code;
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Code::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Code::VERSION = '2.0000';
+}
 use Moose::Role;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-use Moose::Meta::Method::Accessor::Native::Code::execute;
-use Moose::Meta::Method::Accessor::Native::Code::execute_method;
-
 with 'Moose::Meta::Attribute::Native::Trait';
 
 sub _helper_type { 'CodeRef' }
@@ -18,10 +17,6 @@ no Moose::Role;
 
 =pod
 
-=head1 NAME
-
-Moose::Meta::Attribute::Native::Trait::Code - Helper trait for Code attributes
-
 =head1 SYNOPSIS
 
   package Foo;
@@ -69,17 +64,4 @@ Calls the coderef with the the instance as invocant and given args.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
-
-  Florian Ragwitz <rafl@debian.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2010 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
