@@ -1,16 +1,13 @@
 
 package Moose::Meta::Attribute::Native::Trait::Counter;
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Counter::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Native::Trait::Counter::VERSION = '2.0000';
+}
 use Moose::Role;
 
-our $VERSION   = '1.25';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
-use Moose::Meta::Method::Accessor::Native::Counter::dec;
-use Moose::Meta::Method::Accessor::Native::Counter::inc;
-use Moose::Meta::Method::Accessor::Native::Counter::reset;
-use Moose::Meta::Method::Accessor::Native::Counter::set;
-
 with 'Moose::Meta::Attribute::Native::Trait' =>
     { -excludes => ['_root_types'] };
 
@@ -23,7 +20,9 @@ no Moose::Role;
 
 1;
 
-__END__
+# ABSTRACT: Helper trait for counters
+
+
 
 =pod
 
@@ -31,6 +30,10 @@ __END__
 
 Moose::Meta::Attribute::Native::Trait::Counter - Helper trait for counters
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   package MyHomePage;
@@ -107,15 +110,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
