@@ -1,13 +1,15 @@
 
 package Moose::Meta::Instance;
+BEGIN {
+  $Moose::Meta::Instance::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Instance::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.24';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Class::MOP::MiniTrait;
 
 use base "Class::MOP::Instance";
@@ -16,7 +18,9 @@ Class::MOP::MiniTrait::apply(__PACKAGE__, 'Moose::Meta::Object::Trait');
 
 1;
 
-__END__
+# ABSTRACT: The Moose Instance metaclass
+
+
 
 =pod
 
@@ -24,6 +28,10 @@ __END__
 
 Moose::Meta::Instance - The Moose Instance metaclass
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
     # nothing to see here
@@ -51,17 +59,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Yuval Kogman E<lt>nothingmuch@woobling.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
