@@ -1,14 +1,16 @@
 package Moose::Meta::Method::Accessor::Native::Array::get;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::get::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::get::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
 use Class::MOP::MiniTrait;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader' => {
@@ -33,10 +35,10 @@ sub _inline_check_arguments {
 }
 
 sub _return_value {
-    my $self        = shift;
-    my $slot_access = shift;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "${slot_access}->[ \$_[0] ]";
+    return $slot_access . '->[ $_[0] ]';
 }
 
 1;
