@@ -1,4 +1,10 @@
 package Moose::Meta::Method::Accessor::Native::Array::reduce;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::reduce::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::reduce::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -6,10 +12,6 @@ use warnings;
 use List::Util ();
 use Params::Util ();
 
-our $VERSION = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader' => {
@@ -29,16 +31,20 @@ sub _maximum_arguments { 1 }
 sub _inline_check_arguments {
     my $self = shift;
 
-    return $self->_inline_throw_error(
-        q{'The argument passed to reduce must be a code reference'})
-        . q{ unless Params::Util::_CODELIKE( $_[0] );};
+    return (
+        'if (!Params::Util::_CODELIKE($_[0])) {',
+            $self->_inline_throw_error(
+                '"The argument passed to reduce must be a code reference"',
+            ) . ';',
+        '}',
+    );
 }
 
 sub _return_value {
-    my $self        = shift;
-    my $slot_access = shift;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "List::Util::reduce { \$_[0]->( \$a, \$b ) } \@{ ($slot_access) }";
+    return 'List::Util::reduce { $_[0]->($a, $b) } @{ (' . $slot_access . ') }';
 }
 
 no Moose::Role;
