@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Array::set;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::set::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Array::set::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Array::Writer' => {
@@ -15,6 +17,7 @@ with 'Moose::Meta::Method::Accessor::Native::Array::Writer' => {
             _minimum_arguments
             _maximum_arguments
             _inline_check_arguments
+            _inline_coerce_new_values
             _new_members
             _inline_optimized_set_new_value
             _return_value
@@ -35,37 +38,42 @@ sub _inline_check_arguments {
 sub _adds_members { 1 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return
-        "( do { my \@potential = \@{ ($slot_access) }; \$potential[ \$_[0] ] = \$_[1]; \\\@potential } )";
+    return '(do { '
+             . 'my @potential = @{ (' . $slot_access . ') }; '
+             . '$potential[$_[0]] = $_[1]; '
+             . '\@potential; '
+         . '})';
 }
 
 # We need to override this because while @_ can be written to, we cannot write
 # directly to $_[1].
-around _inline_coerce_new_values => sub {
-    shift;
+sub _inline_coerce_new_values {
     my $self = shift;
 
-    return q{} unless $self->associated_attribute->should_coerce;
+    return unless $self->associated_attribute->should_coerce;
 
-    return q{} unless $self->_tc_member_type_can_coerce;
+    return unless $self->_tc_member_type_can_coerce;
 
-    return '@_ = ( $_[0], $member_tc_obj->coerce( $_[1] ) );';
+    return '@_ = ($_[0], $member_tc_obj->coerce($_[1]));';
 };
 
 sub _new_members { '$_[1]' }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "${slot_access}->[ \$_[0] ] = \$_[1]";
+    return $slot_access . '->[$_[0]] = $_[1];';
 }
 
 sub _return_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "return ${slot_access}->[ \$_[0] ];";
+    return $slot_access . '->[$_[0]]';
 }
 
 no Moose::Role;
