@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Bool::set;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Bool::set::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Bool::set::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -23,9 +25,10 @@ sub _maximum_arguments { 0 }
 sub _potential_value { 1 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access = 1";
+    return $slot_access . ' = 1;';
 }
 
 no Moose::Role;
