@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Bool::toggle;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Bool::toggle::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Bool::toggle::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.25';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -21,15 +23,17 @@ with 'Moose::Meta::Method::Accessor::Native::Writer' => {
 sub _maximum_arguments { 0 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "$slot_access ? 0 : 1";
+    return $slot_access . ' ? 0 : 1';
 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access = $slot_access ? 0 : 1";
+    return $slot_access . ' = ' . $slot_access . ' ? 0 : 1;';
 }
 
 no Moose::Role;
