@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Counter::Writer;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::Writer::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::Writer::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer';
@@ -17,8 +19,9 @@ sub _constraint_must_be_checked {
     my $attr = $self->associated_attribute;
 
     return $attr->has_type_constraint
-        && ( $attr->type_constraint->name =~ /^(?:Num|Int)$/
-        || ( $attr->should_coerce && $attr->type_constraint->has_coercion ) );
+        && ($attr->type_constraint->name =~ /^(?:Num|Int)$/
+         || ($attr->should_coerce && $attr->type_constraint->has_coercion)
+           );
 }
 
 no Moose::Role;
