@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Counter::inc;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::inc::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::inc::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.25';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -23,15 +25,17 @@ sub _minimum_arguments { 0 }
 sub _maximum_arguments { 1 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "$slot_access + ( defined \$_[0] ? \$_[0] : 1 )";
+    return $slot_access . ' + (defined $_[0] ? $_[0] : 1)';
 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access += defined \$_[0] ? \$_[0] : 1";
+    return $slot_access . ' += defined $_[0] ? $_[0] : 1;';
 }
 
 no Moose::Role;
