@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Counter::reset;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::reset::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Counter::reset::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -21,15 +23,17 @@ with 'Moose::Meta::Method::Accessor::Native::Writer' => {
 sub _maximum_arguments { 0 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "\$attr->default(\$self)"
+    return '$attr->default($self)';
 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access = \$attr->default(\$self)";
+    return $slot_access . ' = $attr->default($self);';
 }
 
 no Moose::Role;
