@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Hash::clear;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Hash::clear::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Hash::clear::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Hash::Writer' => {
@@ -23,15 +25,16 @@ sub _maximum_arguments { 0 }
 
 sub _adds_members { 0 }
 
-sub _potential_value { return '{}' }
+sub _potential_value { '{}' }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access = {}";
+    return $slot_access . ' = {};';
 }
 
-sub _return_value { return q{} }
+sub _return_value { '' }
 
 no Moose::Role;
 
