@@ -1,14 +1,16 @@
 package Moose::Meta::Method::Accessor::Native::Hash::is_empty;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Hash::is_empty::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Hash::is_empty::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
 use Scalar::Util qw( looks_like_number );
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader' =>
@@ -17,10 +19,10 @@ with 'Moose::Meta::Method::Accessor::Native::Reader' =>
 sub _maximum_arguments { 0 }
 
 sub _return_value {
-    my $self        = shift;
-    my $slot_access = shift;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "scalar keys \%{ ($slot_access) } ? 0 : 1";
+    return 'scalar keys %{ (' . $slot_access . ') } ? 0 : 1';
 }
 
 no Moose::Role;
