@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::Number::mul;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Number::mul::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::Number::mul::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Writer' => {
@@ -19,20 +21,22 @@ with 'Moose::Meta::Method::Accessor::Native::Writer' => {
     ]
     };
 
-sub _minimum_arguments {1}
+sub _minimum_arguments { 1 }
 
-sub _maximum_arguments {1}
+sub _maximum_arguments { 1 }
 
 sub _potential_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "$slot_access * \$_[0]";
+    return $slot_access . ' * $_[0]';
 }
 
 sub _inline_optimized_set_new_value {
-    my ( $self, $inv, $new, $slot_access ) = @_;
+    my $self = shift;
+    my ($inv, $new, $slot_access) = @_;
 
-    return "$slot_access *= \$_[0]";
+    return $slot_access . ' *= $_[0];';
 }
 
 no Moose::Role;
