@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Accessor::Native::String::length;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::String::length::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::String::length::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader' =>
@@ -15,9 +17,10 @@ with 'Moose::Meta::Method::Accessor::Native::Reader' =>
 sub _maximum_arguments { 0 }
 
 sub _return_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "length $slot_access";
+    return 'length ' . $slot_access;
 }
 
 no Moose::Role;
