@@ -1,4 +1,10 @@
 package Moose::Meta::Method::Accessor::Native::String::match;
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::String::match::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Accessor::Native::String::match::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -6,10 +12,6 @@ use warnings;
 use Moose::Util ();
 use Params::Util ();
 
-our $VERSION = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader' => {
@@ -29,15 +31,21 @@ sub _maximum_arguments { 1 }
 sub _inline_check_arguments {
     my $self = shift;
 
-    return $self->_inline_throw_error(
-        q{'The argument passed to match must be a string or regexp reference'}
-    ) . q{ unless Moose::Util::_STRINGLIKE0( $_[0] ) || Params::Util::_REGEX( $_[0] );};
+    return (
+        'if (!Moose::Util::_STRINGLIKE0($_[0]) && !Params::Util::_REGEX($_[0])) {',
+            $self->_inline_throw_error(
+                '"The argument passed to match must be a string or regexp '
+              . 'reference"',
+            ) . ';',
+        '}',
+    );
 }
 
 sub _return_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "$slot_access =~ \$_[0]";
+    return $slot_access . ' =~ $_[0]';
 }
 
 no Moose::Role;
