@@ -1,5 +1,11 @@
 
 package Moose::Meta::Method::Delegation;
+BEGIN {
+  $Moose::Meta::Method::Delegation::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Delegation::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -7,10 +13,6 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Method',
          'Class::MOP::Method::Generated';
 
@@ -133,7 +135,9 @@ sub _get_delegate_accessor {
 
 1;
 
-__END__
+# ABSTRACT: A Moose Method metaclass for delegation methods
+
+
 
 =pod
 
@@ -141,6 +145,10 @@ __END__
 
 Moose::Meta::Method::Delegation - A Moose Method metaclass for delegation methods
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This is a subclass of L<Moose::Meta::Method> for delegation
@@ -194,15 +202,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Dave Rolsky E<lt>autarch@urth.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
