@@ -1,13 +1,15 @@
 
 package Moose::Meta::Method::Meta;
+BEGIN {
+  $Moose::Meta::Method::Meta::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Meta::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Method',
          'Class::MOP::Method::Meta';
 
@@ -31,7 +33,9 @@ sub _make_compatible_with {
 
 1;
 
-__END__
+# ABSTRACT: A Moose Method metaclass for C<meta> methods
+
+
 
 =pod
 
@@ -39,6 +43,10 @@ __END__
 
 Moose::Meta::Method::Meta - A Moose Method metaclass for C<meta> methods
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class is a subclass of L<Class::MOP::Method::Meta> that
@@ -54,15 +62,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Jesse Luehrs E<lt>doy at tozt dot net<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
