@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Overridden;
+BEGIN {
+  $Moose::Meta::Method::Overridden::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Method::Overridden::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.24';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Method';
 
 sub new {
@@ -49,7 +51,9 @@ sub new {
 
 1;
 
-__END__
+# ABSTRACT: A Moose Method metaclass for overridden methods
+
+
 
 =pod
 
@@ -57,6 +61,10 @@ __END__
 
 Moose::Meta::Method::Overridden - A Moose Method metaclass for overridden methods
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class implements method overriding logic for the L<Moose>
@@ -100,15 +108,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
