@@ -1,11 +1,14 @@
 package Moose::Meta::Mixin::AttributeCore;
+BEGIN {
+  $Moose::Meta::Mixin::AttributeCore::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Mixin::AttributeCore::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.22';
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Class::MOP::Mixin::AttributeCore';
 
 __PACKAGE__->meta->add_attribute( 'isa'  => ( reader => '_isa_metadata' ) );
@@ -48,7 +51,9 @@ __PACKAGE__->meta->add_attribute(
 
 1;
 
-__END__
+# ABSTRACT: Core attributes shared by attribute metaclasses
+
+
 
 =pod
 
@@ -56,6 +61,10 @@ __END__
 
 Moose::Meta::Mixin::AttributeCore - Core attributes shared by attribute metaclasses
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class implements the core attributes (aka properties) shared by all Moose
@@ -65,17 +74,19 @@ attributes. See the L<Moose::Meta::Attribute> documentation for API details.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Dave Rolsky E<lt>autarch@urth.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
