@@ -1,13 +1,15 @@
 package Moose::Meta::Role::Application;
+BEGIN {
+  $Moose::Meta::Role::Application::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Application::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 use metaclass;
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 __PACKAGE__->meta->add_attribute('method_exclusions' => (
     init_arg => '-excludes',
     reader   => 'get_method_exclusions',
@@ -76,7 +78,9 @@ sub apply_after_method_modifiers    { (shift)->apply_method_modifiers('after'  =
 
 1;
 
-__END__
+# ABSTRACT: A base class for role application
+
+
 
 =pod
 
@@ -84,6 +88,10 @@ __END__
 
 Moose::Meta::Role::Application - A base class for role application
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This is the abstract base class for role applications.
@@ -139,16 +147,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
