@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Application::RoleSummation;
+BEGIN {
+  $Moose::Meta::Role::Application::RoleSummation::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Application::RoleSummation::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -8,10 +14,6 @@ use Scalar::Util 'blessed';
 
 use Moose::Meta::Role::Composite;
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role::Application';
 
 __PACKAGE__->meta->add_attribute('role_params' => (
@@ -138,7 +140,7 @@ sub apply_attributes {
                 "We have encountered an attribute conflict with '$name' "
                     . "during role composition. "
                     . " This attribute is defined in both $role1 and $role2."
-                    . " This is fatal error and cannot be disambiguated." );
+                    . " This is a fatal error and cannot be disambiguated." );
         }
 
         $seen{$name} = $attr;
@@ -254,7 +256,9 @@ sub apply_method_modifiers {
 
 1;
 
-__END__
+# ABSTRACT: Combine two or more roles
+
+
 
 =pod
 
@@ -262,6 +266,10 @@ __END__
 
 Moose::Meta::Role::Application::RoleSummation - Combine two or more roles
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 Summation composes two traits, forming the union of non-conflicting
@@ -311,16 +319,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
