@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Application::ToClass;
+BEGIN {
+  $Moose::Meta::Role::Application::ToClass::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Application::ToClass::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -7,10 +13,6 @@ use metaclass;
 use Moose::Util  'english_list';
 use Scalar::Util 'weaken', 'blessed';
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role::Application';
 
 __PACKAGE__->meta->add_attribute('role' => (
@@ -129,7 +131,6 @@ sub check_required_attributes {
 
 sub apply_attributes {
     my ($self, $role, $class) = @_;
-    my $attr_metaclass = $class->attribute_metaclass;
 
     foreach my $attribute_name ($role->get_attribute_list) {
         # it if it has one already
@@ -140,7 +141,7 @@ sub apply_attributes {
         }
         else {
             $class->add_attribute(
-                $role->get_attribute($attribute_name)->attribute_for_class($attr_metaclass)
+                $role->get_attribute($attribute_name)->attribute_for_class
             );
         }
     }
@@ -224,7 +225,9 @@ sub apply_method_modifiers {
 
 1;
 
-__END__
+# ABSTRACT: Compose a role into a class
+
+
 
 =pod
 
@@ -232,6 +235,10 @@ __END__
 
 Moose::Meta::Role::Application::ToClass - Compose a role into a class
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 =head2 METHODS
@@ -266,16 +273,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
