@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Application::ToInstance;
+BEGIN {
+  $Moose::Meta::Role::Application::ToInstance::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Application::ToInstance::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -6,10 +12,6 @@ use metaclass;
 
 use Scalar::Util 'blessed';
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role::Application';
 
 __PACKAGE__->meta->add_attribute('rebless_params' => (
@@ -39,7 +41,9 @@ sub apply {
 
 1;
 
-__END__
+# ABSTRACT: Compose a role into an instance
+
+
 
 =pod
 
@@ -47,6 +51,10 @@ __END__
 
 Moose::Meta::Role::Application::ToInstance - Compose a role into an instance
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 =head2 METHODS
@@ -69,16 +77,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
