@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Composite;
+BEGIN {
+  $Moose::Meta::Role::Composite::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Composite::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -6,10 +12,6 @@ use metaclass;
 
 use Scalar::Util 'blessed';
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role';
 
 # NOTE:
@@ -146,7 +148,9 @@ sub reinitialize {
 
 1;
 
-__END__
+# ABSTRACT: An object to represent the set of roles
+
+
 
 =pod
 
@@ -154,6 +158,10 @@ __END__
 
 Moose::Meta::Role::Composite - An object to represent the set of roles
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 A composite is a role that consists of a set of two or more roles.
@@ -207,15 +215,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
