@@ -1,5 +1,11 @@
 
 package Moose::Meta::Role::Method::Conflicting;
+BEGIN {
+  $Moose::Meta::Role::Method::Conflicting::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::Role::Method::Conflicting::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -8,10 +14,6 @@ use Moose::Util;
 
 use base qw(Moose::Meta::Role::Method::Required);
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 __PACKAGE__->meta->add_attribute('roles' => (
     reader   => 'roles',
     required => 1,
@@ -24,7 +26,9 @@ sub roles_as_english_list {
 
 1;
 
-__END__
+# ABSTRACT: A Moose metaclass for conflicting methods in Roles
+
+
 
 =pod
 
@@ -32,6 +36,10 @@ __END__
 
 Moose::Meta::Role::Method::Conflicting - A Moose metaclass for conflicting methods in Roles
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 =head1 INHERITANCE
@@ -80,15 +88,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
