@@ -1,5 +1,11 @@
 
 package Moose::Meta::TypeCoercion;
+BEGIN {
+  $Moose::Meta::TypeCoercion::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeCoercion::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -8,10 +14,6 @@ use metaclass;
 use Moose::Meta::Attribute;
 use Moose::Util::TypeConstraints ();
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 __PACKAGE__->meta->add_attribute('type_coercion_map' => (
     reader  => 'type_coercion_map',
     default => sub { [] }
@@ -99,7 +101,9 @@ sub coerce { $_[0]->_compiled_type_coercion->($_[1]) }
 
 1;
 
-__END__
+# ABSTRACT: The Moose Type Coercion metaclass
+
+
 
 =pod
 
@@ -107,6 +111,10 @@ __END__
 
 Moose::Meta::TypeCoercion - The Moose Type Coercion metaclass
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 A type coercion object is basically a mapping of one or more type
@@ -178,15 +186,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
