@@ -1,5 +1,11 @@
 
 package Moose::Meta::TypeConstraint;
+BEGIN {
+  $Moose::Meta::TypeConstraint::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -15,10 +21,6 @@ use Sub::Name qw(subname);
 
 use base qw(Class::MOP::Object);
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 __PACKAGE__->meta->add_attribute('name'       => (reader => 'name'));
 __PACKAGE__->meta->add_attribute('parent'     => (
     reader    => 'parent',
@@ -321,7 +323,9 @@ sub create_child_type {
 
 1;
 
-__END__
+# ABSTRACT: The Moose Type Constraint metaclass
+
+
 
 =pod
 
@@ -329,6 +333,10 @@ __END__
 
 Moose::Meta::TypeConstraint - The Moose Type Constraint metaclass
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class represents a single type constraint. Moose's built-in type
@@ -499,15 +507,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
