@@ -1,4 +1,10 @@
 package Moose::Meta::TypeConstraint::Class;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Class::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::Class::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -7,10 +13,6 @@ use metaclass;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints ();
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeConstraint';
 
 __PACKAGE__->meta->add_attribute('class' => (
@@ -34,7 +36,7 @@ sub _create_hand_optimized_type_constraint {
     my $class = $self->class;
     $self->hand_optimized_type_constraint(
         sub {
-            blessed( $_[0] ) && blessed( $_[0] ) ne 'Regexp' && $_[0]->isa($class)
+            blessed( $_[0] ) && $_[0]->isa($class)
         }
     );
 }
@@ -121,7 +123,9 @@ sub get_message {
 
 1;
 
-__END__
+# ABSTRACT: Class/TypeConstraint parallel hierarchy
+
+
 
 =pod
 
@@ -129,6 +133,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Class - Class/TypeConstraint parallel hierarchy
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class represents type constraints for a class.
@@ -194,15 +202,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
