@@ -1,13 +1,15 @@
 package Moose::Meta::TypeConstraint::Parameterizable;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Parameterizable::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::Parameterizable::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 use metaclass;
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeConstraint';
 use Moose::Meta::TypeConstraint::Parameterized;
 use Moose::Util::TypeConstraints ();
@@ -81,7 +83,8 @@ sub parameterize {
 
 1;
 
-__END__
+# ABSTRACT: Type constraints which can take a parameter (ArrayRef)
+
 
 
 =pod
@@ -90,6 +93,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Parameterizable - Type constraints which can take a parameter (ArrayRef)
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class represents a parameterizable type constraint. This is a
@@ -118,15 +125,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
