@@ -1,4 +1,10 @@
 package Moose::Meta::TypeConstraint::Parameterized;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Parameterized::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::Parameterized::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -8,10 +14,6 @@ use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
 use Moose::Meta::TypeConstraint::Parameterizable;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeConstraint';
 
 __PACKAGE__->meta->add_attribute('type_parameter' => (
@@ -69,7 +71,8 @@ sub create_child_type {
 
 1;
 
-__END__
+# ABSTRACT: Type constraints with a bound parameter (ArrayRef[Int])
+
 
 
 =pod
@@ -78,6 +81,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Parameterized - Type constraints with a bound parameter (ArrayRef[Int])
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 METHODS
 
 This class is intentionally not documented because the API is
@@ -94,15 +101,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
