@@ -1,4 +1,10 @@
 package Moose::Meta::TypeConstraint::Role;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Role::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::Role::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -7,10 +13,6 @@ use metaclass;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints ();
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeConstraint';
 
 __PACKAGE__->meta->add_attribute('role' => (
@@ -102,7 +104,9 @@ sub create_child_type {
 
 1;
 
-__END__
+# ABSTRACT: Role/TypeConstraint parallel hierarchy
+
+
 
 =pod
 
@@ -110,6 +114,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Role - Role/TypeConstraint parallel hierarchy
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This class represents type constraints for a role.
@@ -169,15 +177,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
