@@ -1,5 +1,11 @@
 
 package Moose::Meta::TypeConstraint::Union;
+BEGIN {
+  $Moose::Meta::TypeConstraint::Union::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Meta::TypeConstraint::Union::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -9,10 +15,6 @@ use Moose::Meta::TypeCoercion::Union;
 
 use List::Util qw(first);
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::TypeConstraint';
 
 __PACKAGE__->meta->add_attribute('type_constraints' => (
@@ -164,7 +166,9 @@ sub create_child_type {
 
 1;
 
-__END__
+# ABSTRACT: A union of Moose type constraints
+
+
 
 =pod
 
@@ -172,6 +176,10 @@ __END__
 
 Moose::Meta::TypeConstraint::Union - A union of Moose type constraints
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 DESCRIPTION
 
 This metaclass represents a union of type constraints. A union takes
@@ -256,15 +264,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
