@@ -1,4 +1,10 @@
 package Moose::Role;
+BEGIN {
+  $Moose::Role::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Role::VERSION = '2.0000';
+}
 use strict;
 use warnings;
 
@@ -7,10 +13,6 @@ use Carp         'croak';
 
 use Sub::Exporter;
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose       ();
 use Moose::Util ();
 
@@ -151,7 +153,9 @@ sub init_meta {
 
 1;
 
-__END__
+# ABSTRACT: The Moose Role
+
+
 
 =pod
 
@@ -159,6 +163,10 @@ __END__
 
 Moose::Role - The Moose Role
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   package Eq;
@@ -295,17 +303,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Christian Hansen E<lt>chansen@cpan.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
