@@ -1,4 +1,10 @@
 package Moose::Util;
+BEGIN {
+  $Moose::Util::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Util::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -10,11 +16,7 @@ use Scalar::Util 'blessed';
 use List::Util qw(first);
 use List::MoreUtils qw(any all);
 use overload ();
-use Class::MOP   0.60;
-
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+use Class::MOP;
 
 my @exports = qw[
     find_meta
@@ -453,7 +455,9 @@ sub _is_role_only_subclass {
 
 1;
 
-__END__
+# ABSTRACT: Utilities for working with Moose classes
+
+
 
 =pod
 
@@ -461,6 +465,10 @@ __END__
 
 Moose::Util - Utilities for working with Moose classes
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   use Moose::Util qw/find_meta does_role search_class_by_role/;
@@ -589,22 +597,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Anders Nor Berle E<lt>debolaz@gmail.comE<gt>
-
-B<with contributions from:>
-
-Robert (phaylon) Sedlacek
-
-Stevan Little
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
