@@ -1,22 +1,27 @@
 package Moose::Util::MetaRole;
+BEGIN {
+  $Moose::Util::MetaRole::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Util::MetaRole::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 use Scalar::Util 'blessed';
 
-our $VERSION   = '1.22';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
+use Carp qw( croak );
 use List::MoreUtils qw( all );
 use List::Util qw( first );
 use Moose::Deprecated;
+use Scalar::Util qw( blessed );
 
 sub apply_metaclass_roles {
     Moose::Deprecated::deprecated(
         feature => 'pre-0.94 MetaRole API',
         message =>
-            'The old Moose::Util::MetaRole API (before version 0.94) has been deprecated'
+            'The old Moose::Util::MetaRole API (before version 0.94) has been deprecated.'
+            . ' Using this API will throw an error in Moose 2.0200.'
     );
 
     goto &apply_metaroles;
@@ -27,10 +32,7 @@ sub apply_metaroles {
 
     _fixup_old_style_args(\%args);
 
-    my $for
-        = blessed $args{for}
-        ? $args{for}
-        : Class::MOP::class_of( $args{for} );
+    my $for = _metathing_for( $args{for} );
 
     if ( $for->isa('Moose::Meta::Role') ) {
         return _make_new_metaclass( $for, $args{role_metaroles}, 'role' );
@@ -40,6 +42,46 @@ sub apply_metaroles {
     }
 }
 
+sub _metathing_for {
+    my $passed = shift;
+
+    my $found
+        = blessed $passed
+        ? $passed
+        : Class::MOP::class_of($passed);
+
+    return $found
+        if defined $found
+            && blessed $found
+            && (   $found->isa('Moose::Meta::Role')
+                || $found->isa('Moose::Meta::Class') );
+
+    local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+
+    my $error_start
+        = 'When using Moose::Util::MetaRole, you must pass a Moose class name,'
+        . ' role name, metaclass object, or metarole object.';
+
+    if ( defined $found && blessed $found ) {
+        croak $error_start
+            . " You passed $passed, and we resolved this to a "
+            . ( blessed $found )
+            . ' object.';
+    }
+
+    if ( defined $passed && !defined $found ) {
+        croak $error_start
+            . " You passed $passed, and this did not resolve to a metaclass or metarole."
+            . ' Maybe you need to call Moose->init_meta to initialize the metaclass first?';
+    }
+
+    if ( !defined $passed ) {
+        croak $error_start
+            . " You passed an undef."
+            . ' Maybe you need to call Moose->init_meta to initialize the metaclass first?';
+    }
+}
+
 sub _fixup_old_style_args {
     my $args = shift;
 
@@ -48,7 +90,8 @@ sub _fixup_old_style_args {
     Moose::Deprecated::deprecated(
         feature => 'pre-0.94 MetaRole API',
         message =>
-            'The old Moose::Util::MetaRole API (before version 0.94) has been deprecated'
+            'The old Moose::Util::MetaRole API (before version 0.94) has been deprecated.'
+            . ' Using this API will throw an error in Moose 2.0200.'
     );
 
     $args->{for} = delete $args->{for_class}
@@ -133,12 +176,12 @@ sub _make_new_metaclass {
 sub apply_base_class_roles {
     my %args = @_;
 
-    my $for = $args{for} || $args{for_class};
-
-    my $meta = Class::MOP::class_of($for);
+    my $meta = _metathing_for( $args{for} || $args{for_class} );
+    croak 'You can only apply base class roles to a Moose class, not a role.'
+        if $meta->isa('Moose::Meta::Role');
 
     my $new_base = _make_new_class(
-        $for,
+        $meta->name,
         $args{roles},
         [ $meta->superclasses() ],
     );
@@ -169,12 +212,20 @@ sub _make_new_class {
 
 1;
 
-__END__
+# ABSTRACT: Apply roles to any metaclass, as well as the object base class
+
+
+
+=pod
 
 =head1 NAME
 
 Moose::Util::MetaRole - Apply roles to any metaclass, as well as the object base class
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   package MyApp::Moose;
@@ -318,15 +369,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Dave Rolsky E<lt>autarch@urth.orgE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
