@@ -1,4 +1,10 @@
 package Moose::Util::TypeConstraints::OptimizedConstraints;
+BEGIN {
+  $Moose::Util::TypeConstraints::OptimizedConstraints::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Moose::Util::TypeConstraints::OptimizedConstraints::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -7,19 +13,16 @@ use Class::MOP;
 use Moose::Deprecated;
 use Scalar::Util 'blessed', 'looks_like_number';
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 sub Value { defined($_[0]) && !ref($_[0]) }
 
 sub Ref { ref($_[0]) }
 
-# We need to use a temporary here to flatten LVALUEs, for instance as in
+# We might need to use a temporary here to flatten LVALUEs, for instance as in
 # Str(substr($_,0,255)).
 sub Str {
-    my $value = $_[0];
-    defined($value) && ref(\$value) eq 'SCALAR'
+    defined($_[0])
+      && (   ref(\             $_[0] ) eq 'SCALAR'
+          || ref(\(my $value = $_[0])) eq 'SCALAR')
 }
 
 sub Num { !ref($_[0]) && looks_like_number($_[0]) }
@@ -28,25 +31,26 @@ sub Num { !ref($_[0]) && looks_like_number($_[0]) }
 # and that confuses some things (like JSON.pm)
 sub Int {
     my $value = $_[0];
-    defined($value) && !ref($value) && $value =~ /^-?[0-9]+$/
+    defined($value) && !ref($value) && $value =~ /\A-?[0-9]+\z/
 }
 
 sub ScalarRef { ref($_[0]) eq 'SCALAR' || ref($_[0]) eq 'REF' }
 sub ArrayRef  { ref($_[0]) eq 'ARRAY'  }
 sub HashRef   { ref($_[0]) eq 'HASH'   }
 sub CodeRef   { ref($_[0]) eq 'CODE'   }
-sub RegexpRef { ref($_[0]) eq 'Regexp' }
 sub GlobRef   { ref($_[0]) eq 'GLOB'   }
 
+# RegexpRef is implemented in Moose.xs
+
 sub FileHandle { ref($_[0]) eq 'GLOB' && Scalar::Util::openhandle($_[0]) or blessed($_[0]) && $_[0]->isa("IO::Handle") }
 
-sub Object { blessed($_[0]) && blessed($_[0]) ne 'Regexp' }
+sub Object { blessed($_[0]) }
 
 sub Role {
     Moose::Deprecated::deprecated(
         feature => 'Role type',
         message =>
-            'The Role type has been deprecated. Maybe you meant to create a RoleName type?'
+            'The Role type has been deprecated. Maybe you meant to create a RoleName type? This type be will be removed in Moose 2.0200.'
     );
     blessed( $_[0] ) && $_[0]->can('does');
 }
@@ -123,17 +127,4 @@ no user serviceable parts inside.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
-
-Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2007-2010 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
