@@ -1,4 +1,10 @@
 package Test::Moose;
+BEGIN {
+  $Test::Moose::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $Test::Moose::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
@@ -9,10 +15,6 @@ use Test::Builder;
 use List::MoreUtils 'all';
 use Moose::Util 'does_role', 'find_meta';
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 my @exports = qw[
     meta_ok
     does_ok
@@ -84,7 +86,9 @@ sub with_immutable (&@) {
 
 1;
 
-__END__
+# ABSTRACT: Test functions for Moose specific features
+
+
 
 =pod
 
@@ -92,6 +96,10 @@ __END__
 
 Test::Moose - Test functions for Moose specific features
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   use Test::More plan => 1;
@@ -167,18 +175,18 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Anders Nor Berle E<lt>debolaz@gmail.comE<gt>
-
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
