@@ -1,14 +1,16 @@
 package oose;
+BEGIN {
+  $oose::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $oose::VERSION = '2.0000';
+}
 
 use strict;
 use warnings;
 
 use Class::MOP;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 BEGIN {
     my $package;
     sub import {
@@ -23,7 +25,9 @@ BEGIN {
 
 1;
 
-__END__
+# ABSTRACT: syntactic sugar to make Moose one-liners easier
+
+
 
 =pod
 
@@ -31,6 +35,10 @@ __END__
 
 oose - syntactic sugar to make Moose one-liners easier
 
+=head1 VERSION
+
+version 2.0000
+
 =head1 SYNOPSIS
 
   # create a Moose class on the fly ...
@@ -76,15 +84,17 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Chris Prather  C<< <chris@prather.org> >>
+Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
